@@ -35,10 +35,4 @@ class DeleteAlertContactGroupRequest(RpcRequest):
 		return self.get_query_params().get('ContactGroupId')
 
 	def set_ContactGroupId(self,ContactGroupId):
-		self.add_query_param('ContactGroupId',ContactGroupId)
-
-	def get_ProxyUserId(self):
-		return self.get_query_params().get('ProxyUserId')
-
-	def set_ProxyUserId(self,ProxyUserId):
-		self.add_query_param('ProxyUserId',ProxyUserId)
\ No newline at end of file
+		self.add_query_param('ContactGroupId',ContactGroupId)
\ No newline at end of file
