@@ -35,10 +35,4 @@ class DeleteAlertContactRequest(RpcRequest):
 		return self.get_query_params().get('ContactId')
 
 	def set_ContactId(self,ContactId):
-		self.add_query_param('ContactId',ContactId)
-
-	def get_ProxyUserId(self):
-		return self.get_query_params().get('ProxyUserId')
-
-	def set_ProxyUserId(self,ProxyUserId):
-		self.add_query_param('ProxyUserId',ProxyUserId)
\ No newline at end of file
+		self.add_query_param('ContactId',ContactId)
\ No newline at end of file
