@@ -35,10 +35,4 @@ class DeleteAlertRulesRequest(RpcRequest):
 		return self.get_query_params().get('AlertIds')
 
 	def set_AlertIds(self,AlertIds):
-		self.add_query_param('AlertIds',AlertIds)
-
-	def get_ProxyUserId(self):
-		return self.get_query_params().get('ProxyUserId')
-
-	def set_ProxyUserId(self,ProxyUserId):
-		self.add_query_param('ProxyUserId',ProxyUserId)
\ No newline at end of file
+		self.add_query_param('AlertIds',AlertIds)
\ No newline at end of file
