@@ -35,10 +35,4 @@ class StopAlertRequest(RpcRequest):
 		return self.get_query_params().get('AlertId')
 
 	def set_AlertId(self,AlertId):
-		self.add_query_param('AlertId',AlertId)
-
-	def get_ProxyUserId(self):
-		return self.get_query_params().get('ProxyUserId')
-
-	def set_ProxyUserId(self,ProxyUserId):
-		self.add_query_param('ProxyUserId',ProxyUserId)
\ No newline at end of file
+		self.add_query_param('AlertId',AlertId)
\ No newline at end of file
