@@ -43,12 +43,6 @@ class UpdateAlertContactGroupRequest(RpcRequest):
 	def set_ContactGroupName(self,ContactGroupName):
 		self.add_query_param('ContactGroupName',ContactGroupName)
 
-	def get_ProxyUserId(self):
-		return self.get_query_params().get('ProxyUserId')
-
-	def set_ProxyUserId(self,ProxyUserId):
-		self.add_query_param('ProxyUserId',ProxyUserId)
-
 	def get_ContactIds(self):
 		return self.get_query_params().get('ContactIds')
 
